@@ -17,6 +17,10 @@
 from uuid import uuid4
 
 from threading import Thread
+try:  # Python 2
+    from cPickle import PicklingError
+except:  # Python 3
+    from pickle import PicklingError
 
 
 def thread_worker(function, task, *args, **kwargs):
@@ -33,11 +37,14 @@ def process_worker(function, writer, *args, **kwargs):
     except (IOError, OSError):  # pipe was closed
         return
     except Exception as error:
-        writer.send(error)
+        try:
+            writer.send(error)
+        except PicklingError:
+            writer.send(SerializingError(str(error), type(error)))
 
 
 class PebbleError(Exception):
-    """Puddle base exception."""
+    """Pebble base exception."""
     pass
 
 
@@ -47,12 +54,26 @@ class TimeoutError(PebbleError):
         self.msg = msg
 
     def __repr__(self):
-        return str(self.msg)
+        return "%s %s" % (self.__class__, self.msg)
 
     def __str__(self):
         return str(self.msg)
 
 
+class SerializingError(PebbleError):
+    """Raised if unable to serialize an Exception."""
+    def __init__(self, msg, value):
+        super(SerializingError, self).__init__(msg, value)
+        self.msg = msg
+        self.value = value
+
+    def __repr__(self):
+        return "%s %s: %s" % (self.__class__, self.value, self.msg)
+
+    def __str__(self):
+        return "Unable to serialize %s. Message: %s" % (self.value, self.msg)
+
+
 class ThreadTask(object):
     def __init__(self, task_nr, callback, error_callback):
         self.id = uuid4()
